/*****************************************************************************************************************************
--
--    File Name    : sin_cos_write.v 

--    Description  : This module provides the values of sin and cosine
--                   

-- Targeted device : Microsemi-SoC                     
-- Author          : India Solutions Team

-- SVN Revision Information:
-- SVN $Revision: TBD
-- SVN $Date: TBD
--
--
--
-- COPYRIGHT 2016 BY MICROSEMI 
-- THE INFORMATION CONTAINED IN THIS DOCUMENT IS SUBJECT TO LICENSING RESTRICTIONS 
-- FROM MICROSEMI CORP.  IF YOU ARE NOT IN POSSESSION OF WRITTEN AUTHORIZATION FROM 
-- MICROSEMI FOR USE OF THIS FILE, THEN THE FILE SHOULD BE IMMEDIATELY DESTROYED AND 
-- NO BACK-UP OF THE FILE SHOULD BE MADE. 
-- 

--******************************************************************************************************************************/
`timescale 1ns/1ps
module sin_cos_write #(parameter g_SIN_COS_DWIDTH = 10,
                       parameter g_HUE_CONSTANT_WIDTH = 8,
                       parameter g_SIN_COS_MEM_DEPTH = 180)
                     (input wire clock,
                      input wire nreset,
                      output reg write_en,
                      output reg[7 : 0] write_addr,
                      output reg[(g_SIN_COS_DWIDTH - 1) : 0] sin_value_o,
                      output reg[(g_SIN_COS_DWIDTH - 1) : 0] cos_value_o);
  reg[7 : 0] addr_cntr;
  always
    @(posedge clock,
      negedge nreset)
    begin
      if (!nreset)
        begin
          addr_cntr <= 'd0;
        end
      else
        begin
          if (addr_cntr == 'd181)
            addr_cntr <= addr_cntr;
          else
            addr_cntr <= addr_cntr + 1'b1;
        end
    end
  always
    @(posedge clock,
      negedge nreset)
    begin
      if (!nreset)
        begin
          sin_value_o <= 'd0;
          cos_value_o <= 'd0;
          write_addr <= 'd0;
          write_en <= 1'b0;
        end
      else
        begin
          case (addr_cntr)
            'd0:
              begin
                sin_value_o <= 'h000;
                cos_value_o <= 'h1ff;
                write_en <= 1'b1;
                write_addr <= 'd0;
              end
            'd1:
              begin
                sin_value_o <= 'h009;
                cos_value_o <= 'h1ff;
                write_en <= 1'b1;
                write_addr <= 'd1;
              end
            'd2:
              begin
                sin_value_o <= 'h012;
                cos_value_o <= 'h1ff;
                write_en <= 1'b1;
                write_addr <= 'd2;
              end
            'd3:
              begin
                sin_value_o <= 'h01b;
                cos_value_o <= 'h1ff;
                write_en <= 1'b1;
                write_addr <= 'd3;
              end
            'd4:
              begin
                sin_value_o <= 'h024;
                cos_value_o <= 'h1ff;
                write_en <= 1'b1;
                write_addr <= 'd4;
              end
            'd5:
              begin
                sin_value_o <= 'h02d;
                cos_value_o <= 'h1fe;
                write_en <= 1'b1;
                write_addr <= 'd5;
              end
            'd6:
              begin
                sin_value_o <= 'h036;
                cos_value_o <= 'h1fd;
                write_en <= 1'b1;
                write_addr <= 'd6;
              end
            'd7:
              begin
                sin_value_o <= 'h03e;
                cos_value_o <= 'h1fc;
                write_en <= 1'b1;
                write_addr <= 'd7;
              end
            'd8:
              begin
                sin_value_o <= 'h047;
                cos_value_o <= 'h1fb;
                write_en <= 1'b1;
                write_addr <= 'd8;
              end
            'd9:
              begin
                sin_value_o <= 'h050;
                cos_value_o <= 'h1fa;
                write_en <= 1'b1;
                write_addr <= 'd9;
              end
            'd10:
              begin
                sin_value_o <= 'h059;
                cos_value_o <= 'h1f8;
                write_en <= 1'b1;
                write_addr <= 'd10;
              end
            'd11:
              begin
                sin_value_o <= 'h062;
                cos_value_o <= 'h1f7;
                write_en <= 1'b1;
                write_addr <= 'd11;
              end
            'd12:
              begin
                sin_value_o <= 'h06a;
                cos_value_o <= 'h1f5;
                write_en <= 1'b1;
                write_addr <= 'd12;
              end
            'd13:
              begin
                sin_value_o <= 'h073;
                cos_value_o <= 'h1f3;
                write_en <= 1'b1;
                write_addr <= 'd13;
              end
            'd14:
              begin
                sin_value_o <= 'h07c;
                cos_value_o <= 'h1f1;
                write_en <= 1'b1;
                write_addr <= 'd14;
              end
            'd15:
              begin
                sin_value_o <= 'h085;
                cos_value_o <= 'h1ef;
                write_en <= 1'b1;
                write_addr <= 'd15;
              end
            'd16:
              begin
                sin_value_o <= 'h08d;
                cos_value_o <= 'h1ec;
                write_en <= 1'b1;
                write_addr <= 'd16;
              end
            'd17:
              begin
                sin_value_o <= 'h096;
                cos_value_o <= 'h1ea;
                write_en <= 1'b1;
                write_addr <= 'd17;
              end
            'd18:
              begin
                sin_value_o <= 'h09e;
                cos_value_o <= 'h1e7;
                write_en <= 1'b1;
                write_addr <= 'd18;
              end
            'd19:
              begin
                sin_value_o <= 'h0a7;
                cos_value_o <= 'h1e4;
                write_en <= 1'b1;
                write_addr <= 'd19;
              end
            'd20:
              begin
                sin_value_o <= 'h0af;
                cos_value_o <= 'h1e1;
                write_en <= 1'b1;
                write_addr <= 'd20;
              end
            'd21:
              begin
                sin_value_o <= 'h0b7;
                cos_value_o <= 'h1de;
                write_en <= 1'b1;
                write_addr <= 'd21;
              end
            'd22:
              begin
                sin_value_o <= 'h0c0;
                cos_value_o <= 'h1db;
                write_en <= 1'b1;
                write_addr <= 'd22;
              end
            'd23:
              begin
                sin_value_o <= 'h0c8;
                cos_value_o <= 'h1d7;
                write_en <= 1'b1;
                write_addr <= 'd23;
              end
            'd24:
              begin
                sin_value_o <= 'h0d0;
                cos_value_o <= 'h1d4;
                write_en <= 1'b1;
                write_addr <= 'd24;
              end
            'd25:
              begin
                sin_value_o <= 'h0d8;
                cos_value_o <= 'h1d0;
                write_en <= 1'b1;
                write_addr <= 'd25;
              end
            'd26:
              begin
                sin_value_o <= 'h0e0;
                cos_value_o <= 'h1cc;
                write_en <= 1'b1;
                write_addr <= 'd26;
              end
            'd27:
              begin
                sin_value_o <= 'h0e8;
                cos_value_o <= 'h1c8;
                write_en <= 1'b1;
                write_addr <= 'd27;
              end
            'd28:
              begin
                sin_value_o <= 'h0f0;
                cos_value_o <= 'h1c4;
                write_en <= 1'b1;
                write_addr <= 'd28;
              end
            'd29:
              begin
                sin_value_o <= 'h0f8;
                cos_value_o <= 'h1c0;
                write_en <= 1'b1;
                write_addr <= 'd29;
              end
            'd30:
              begin
                sin_value_o <= 'h100;
                cos_value_o <= 'h1bb;
                write_en <= 1'b1;
                write_addr <= 'd30;
              end
            'd31:
              begin
                sin_value_o <= 'h108;
                cos_value_o <= 'h1b7;
                write_en <= 1'b1;
                write_addr <= 'd31;
              end
            'd32:
              begin
                sin_value_o <= 'h10f;
                cos_value_o <= 'h1b2;
                write_en <= 1'b1;
                write_addr <= 'd32;
              end
            'd33:
              begin
                sin_value_o <= 'h117;
                cos_value_o <= 'h1ad;
                write_en <= 1'b1;
                write_addr <= 'd33;
              end
            'd34:
              begin
                sin_value_o <= 'h11e;
                cos_value_o <= 'h1a8;
                write_en <= 1'b1;
                write_addr <= 'd34;
              end
            'd35:
              begin
                sin_value_o <= 'h126;
                cos_value_o <= 'h1a3;
                write_en <= 1'b1;
                write_addr <= 'd35;
              end
            'd36:
              begin
                sin_value_o <= 'h12d;
                cos_value_o <= 'h19e;
                write_en <= 1'b1;
                write_addr <= 'd36;
              end
            'd37:
              begin
                sin_value_o <= 'h134;
                cos_value_o <= 'h199;
                write_en <= 1'b1;
                write_addr <= 'd37;
              end
            'd38:
              begin
                sin_value_o <= 'h13b;
                cos_value_o <= 'h193;
                write_en <= 1'b1;
                write_addr <= 'd38;
              end
            'd39:
              begin
                sin_value_o <= 'h142;
                cos_value_o <= 'h18e;
                write_en <= 1'b1;
                write_addr <= 'd39;
              end
            'd40:
              begin
                sin_value_o <= 'h149;
                cos_value_o <= 'h188;
                write_en <= 1'b1;
                write_addr <= 'd40;
              end
            'd41:
              begin
                sin_value_o <= 'h150;
                cos_value_o <= 'h182;
                write_en <= 1'b1;
                write_addr <= 'd41;
              end
            'd42:
              begin
                sin_value_o <= 'h157;
                cos_value_o <= 'h17c;
                write_en <= 1'b1;
                write_addr <= 'd42;
              end
            'd43:
              begin
                sin_value_o <= 'h15d;
                cos_value_o <= 'h176;
                write_en <= 1'b1;
                write_addr <= 'd43;
              end
            'd44:
              begin
                sin_value_o <= 'h164;
                cos_value_o <= 'h170;
                write_en <= 1'b1;
                write_addr <= 'd44;
              end
            'd45:
              begin
                sin_value_o <= 'h16a;
                cos_value_o <= 'h16a;
                write_en <= 1'b1;
                write_addr <= 'd45;
              end
            'd46:
              begin
                sin_value_o <= 'h170;
                cos_value_o <= 'h164;
                write_en <= 1'b1;
                write_addr <= 'd46;
              end
            'd47:
              begin
                sin_value_o <= 'h176;
                cos_value_o <= 'h15d;
                write_en <= 1'b1;
                write_addr <= 'd47;
              end
            'd48:
              begin
                sin_value_o <= 'h17c;
                cos_value_o <= 'h157;
                write_en <= 1'b1;
                write_addr <= 'd48;
              end
            'd49:
              begin
                sin_value_o <= 'h182;
                cos_value_o <= 'h150;
                write_en <= 1'b1;
                write_addr <= 'd49;
              end
            'd50:
              begin
                sin_value_o <= 'h188;
                cos_value_o <= 'h149;
                write_en <= 1'b1;
                write_addr <= 'd50;
              end
            'd51:
              begin
                sin_value_o <= 'h18e;
                cos_value_o <= 'h142;
                write_en <= 1'b1;
                write_addr <= 'd51;
              end
            'd52:
              begin
                sin_value_o <= 'h193;
                cos_value_o <= 'h13b;
                write_en <= 1'b1;
                write_addr <= 'd52;
              end
            'd53:
              begin
                sin_value_o <= 'h199;
                cos_value_o <= 'h134;
                write_en <= 1'b1;
                write_addr <= 'd53;
              end
            'd54:
              begin
                sin_value_o <= 'h19e;
                cos_value_o <= 'h12d;
                write_en <= 1'b1;
                write_addr <= 'd54;
              end
            'd55:
              begin
                sin_value_o <= 'h1a3;
                cos_value_o <= 'h126;
                write_en <= 1'b1;
                write_addr <= 'd55;
              end
            'd56:
              begin
                sin_value_o <= 'h1a8;
                cos_value_o <= 'h11e;
                write_en <= 1'b1;
                write_addr <= 'd56;
              end
            'd57:
              begin
                sin_value_o <= 'h1ad;
                cos_value_o <= 'h117;
                write_en <= 1'b1;
                write_addr <= 'd57;
              end
            'd58:
              begin
                sin_value_o <= 'h1b2;
                cos_value_o <= 'h10f;
                write_en <= 1'b1;
                write_addr <= 'd58;
              end
            'd59:
              begin
                sin_value_o <= 'h1b7;
                cos_value_o <= 'h108;
                write_en <= 1'b1;
                write_addr <= 'd59;
              end
            'd60:
              begin
                sin_value_o <= 'h1bb;
                cos_value_o <= 'h100;
                write_en <= 1'b1;
                write_addr <= 'd60;
              end
            'd61:
              begin
                sin_value_o <= 'h1c0;
                cos_value_o <= 'h0f8;
                write_en <= 1'b1;
                write_addr <= 'd61;
              end
            'd62:
              begin
                sin_value_o <= 'h1c4;
                cos_value_o <= 'h0f0;
                write_en <= 1'b1;
                write_addr <= 'd62;
              end
            'd63:
              begin
                sin_value_o <= 'h1c8;
                cos_value_o <= 'h0e8;
                write_en <= 1'b1;
                write_addr <= 'd63;
              end
            'd64:
              begin
                sin_value_o <= 'h1cc;
                cos_value_o <= 'h0e0;
                write_en <= 1'b1;
                write_addr <= 'd64;
              end
            'd65:
              begin
                sin_value_o <= 'h1d0;
                cos_value_o <= 'h0d8;
                write_en <= 1'b1;
                write_addr <= 'd65;
              end
            'd66:
              begin
                sin_value_o <= 'h1d4;
                cos_value_o <= 'h0d0;
                write_en <= 1'b1;
                write_addr <= 'd66;
              end
            'd67:
              begin
                sin_value_o <= 'h1d7;
                cos_value_o <= 'h0c8;
                write_en <= 1'b1;
                write_addr <= 'd67;
              end
            'd68:
              begin
                sin_value_o <= 'h1db;
                cos_value_o <= 'h0c0;
                write_en <= 1'b1;
                write_addr <= 'd68;
              end
            'd69:
              begin
                sin_value_o <= 'h1de;
                cos_value_o <= 'h0b7;
                write_en <= 1'b1;
                write_addr <= 'd69;
              end
            'd70:
              begin
                sin_value_o <= 'h1e1;
                cos_value_o <= 'h0af;
                write_en <= 1'b1;
                write_addr <= 'd70;
              end
            'd71:
              begin
                sin_value_o <= 'h1e4;
                cos_value_o <= 'h0a7;
                write_en <= 1'b1;
                write_addr <= 'd71;
              end
            'd72:
              begin
                sin_value_o <= 'h1e7;
                cos_value_o <= 'h09e;
                write_en <= 1'b1;
                write_addr <= 'd72;
              end
            'd73:
              begin
                sin_value_o <= 'h1ea;
                cos_value_o <= 'h096;
                write_en <= 1'b1;
                write_addr <= 'd73;
              end
            'd74:
              begin
                sin_value_o <= 'h1ec;
                cos_value_o <= 'h08d;
                write_en <= 1'b1;
                write_addr <= 'd74;
              end
            'd75:
              begin
                sin_value_o <= 'h1ef;
                cos_value_o <= 'h085;
                write_en <= 1'b1;
                write_addr <= 'd75;
              end
            'd76:
              begin
                sin_value_o <= 'h1f1;
                cos_value_o <= 'h07c;
                write_en <= 1'b1;
                write_addr <= 'd76;
              end
            'd77:
              begin
                sin_value_o <= 'h1f3;
                cos_value_o <= 'h073;
                write_en <= 1'b1;
                write_addr <= 'd77;
              end
            'd78:
              begin
                sin_value_o <= 'h1f5;
                cos_value_o <= 'h06a;
                write_en <= 1'b1;
                write_addr <= 'd78;
              end
            'd79:
              begin
                sin_value_o <= 'h1f7;
                cos_value_o <= 'h062;
                write_en <= 1'b1;
                write_addr <= 'd79;
              end
            'd80:
              begin
                sin_value_o <= 'h1f8;
                cos_value_o <= 'h059;
                write_en <= 1'b1;
                write_addr <= 'd80;
              end
            'd81:
              begin
                sin_value_o <= 'h1fa;
                cos_value_o <= 'h050;
                write_en <= 1'b1;
                write_addr <= 'd81;
              end
            'd82:
              begin
                sin_value_o <= 'h1fb;
                cos_value_o <= 'h047;
                write_en <= 1'b1;
                write_addr <= 'd82;
              end
            'd83:
              begin
                sin_value_o <= 'h1fc;
                cos_value_o <= 'h03e;
                write_en <= 1'b1;
                write_addr <= 'd83;
              end
            'd84:
              begin
                sin_value_o <= 'h1fd;
                cos_value_o <= 'h036;
                write_en <= 1'b1;
                write_addr <= 'd84;
              end
            'd85:
              begin
                sin_value_o <= 'h1fe;
                cos_value_o <= 'h02d;
                write_en <= 1'b1;
                write_addr <= 'd85;
              end
            'd86:
              begin
                sin_value_o <= 'h1ff;
                cos_value_o <= 'h024;
                write_en <= 1'b1;
                write_addr <= 'd86;
              end
            'd87:
              begin
                sin_value_o <= 'h1ff;
                cos_value_o <= 'h01b;
                write_en <= 1'b1;
                write_addr <= 'd87;
              end
            'd88:
              begin
                sin_value_o <= 'h1ff;
                cos_value_o <= 'h012;
                write_en <= 1'b1;
                write_addr <= 'd88;
              end
            'd89:
              begin
                sin_value_o <= 'h1ff;
                cos_value_o <= 'h009;
                write_en <= 1'b1;
                write_addr <= 'd89;
              end
            'd90:
              begin
                sin_value_o <= 'h1ff;
                cos_value_o <= 'h000;
                write_en <= 1'b1;
                write_addr <= 'd90;
              end
            'd91:
              begin
                sin_value_o <= 'h1ff;
                cos_value_o <= 'h3f7;
                write_en <= 1'b1;
                write_addr <= 'd91;
              end
            'd92:
              begin
                sin_value_o <= 'h1ff;
                cos_value_o <= 'h3ee;
                write_en <= 1'b1;
                write_addr <= 'd92;
              end
            'd93:
              begin
                sin_value_o <= 'h1ff;
                cos_value_o <= 'h3e5;
                write_en <= 1'b1;
                write_addr <= 'd93;
              end
            'd94:
              begin
                sin_value_o <= 'h1ff;
                cos_value_o <= 'h3dc;
                write_en <= 1'b1;
                write_addr <= 'd94;
              end
            'd95:
              begin
                sin_value_o <= 'h1fe;
                cos_value_o <= 'h3d3;
                write_en <= 1'b1;
                write_addr <= 'd95;
              end
            'd96:
              begin
                sin_value_o <= 'h1fd;
                cos_value_o <= 'h3ca;
                write_en <= 1'b1;
                write_addr <= 'd96;
              end
            'd97:
              begin
                sin_value_o <= 'h1fc;
                cos_value_o <= 'h3c2;
                write_en <= 1'b1;
                write_addr <= 'd97;
              end
            'd98:
              begin
                sin_value_o <= 'h1fb;
                cos_value_o <= 'h3c9;
                write_en <= 1'b1;
                write_addr <= 'd98;
              end
            'd99:
              begin
                sin_value_o <= 'h1fa;
                cos_value_o <= 'h3b0;
                write_en <= 1'b1;
                write_addr <= 'd99;
              end
            'd100:
              begin
                sin_value_o <= 'h1f8;
                cos_value_o <= 'h3a7;
                write_en <= 1'b1;
                write_addr <= 'd100;
              end
            'd101:
              begin
                sin_value_o <= 'h1f7;
                cos_value_o <= 'h39e;
                write_en <= 1'b1;
                write_addr <= 'd101;
              end
            'd102:
              begin
                sin_value_o <= 'h1f5;
                cos_value_o <= 'h396;
                write_en <= 1'b1;
                write_addr <= 'd102;
              end
            'd103:
              begin
                sin_value_o <= 'h1f3;
                cos_value_o <= 'h38d;
                write_en <= 1'b1;
                write_addr <= 'd103;
              end
            'd104:
              begin
                sin_value_o <= 'h1f1;
                cos_value_o <= 'h384;
                write_en <= 1'b1;
                write_addr <= 'd104;
              end
            'd105:
              begin
                sin_value_o <= 'h1ef;
                cos_value_o <= 'h37b;
                write_en <= 1'b1;
                write_addr <= 'd105;
              end
            'd106:
              begin
                sin_value_o <= 'h1ec;
                cos_value_o <= 'h373;
                write_en <= 1'b1;
                write_addr <= 'd106;
              end
            'd107:
              begin
                sin_value_o <= 'h1ea;
                cos_value_o <= 'h36a;
                write_en <= 1'b1;
                write_addr <= 'd107;
              end
            'd108:
              begin
                sin_value_o <= 'h1e7;
                cos_value_o <= 'h362;
                write_en <= 1'b1;
                write_addr <= 'd108;
              end
            'd109:
              begin
                sin_value_o <= 'h1e4;
                cos_value_o <= 'h359;
                write_en <= 1'b1;
                write_addr <= 'd109;
              end
            'd110:
              begin
                sin_value_o <= 'h1e1;
                cos_value_o <= 'h351;
                write_en <= 1'b1;
                write_addr <= 'd110;
              end
            'd111:
              begin
                sin_value_o <= 'h1de;
                cos_value_o <= 'h349;
                write_en <= 1'b1;
                write_addr <= 'd111;
              end
            'd112:
              begin
                sin_value_o <= 'h1db;
                cos_value_o <= 'h340;
                write_en <= 1'b1;
                write_addr <= 'd112;
              end
            'd113:
              begin
                sin_value_o <= 'h1d7;
                cos_value_o <= 'h338;
                write_en <= 1'b1;
                write_addr <= 'd113;
              end
            'd114:
              begin
                sin_value_o <= 'h1d4;
                cos_value_o <= 'h330;
                write_en <= 1'b1;
                write_addr <= 'd114;
              end
            'd115:
              begin
                sin_value_o <= 'h1d0;
                cos_value_o <= 'h328;
                write_en <= 1'b1;
                write_addr <= 'd115;
              end
            'd116:
              begin
                sin_value_o <= 'h1cc;
                cos_value_o <= 'h320;
                write_en <= 1'b1;
                write_addr <= 'd116;
              end
            'd117:
              begin
                sin_value_o <= 'h1c8;
                cos_value_o <= 'h318;
                write_en <= 1'b1;
                write_addr <= 'd117;
              end
            'd118:
              begin
                sin_value_o <= 'h1c4;
                cos_value_o <= 'h310;
                write_en <= 1'b1;
                write_addr <= 'd118;
              end
            'd119:
              begin
                sin_value_o <= 'h1c0;
                cos_value_o <= 'h308;
                write_en <= 1'b1;
                write_addr <= 'd119;
              end
            'd120:
              begin
                sin_value_o <= 'h1bb;
                cos_value_o <= 'h300;
                write_en <= 1'b1;
                write_addr <= 'd120;
              end
            'd121:
              begin
                sin_value_o <= 'h1b7;
                cos_value_o <= 'h2f8;
                write_en <= 1'b1;
                write_addr <= 'd121;
              end
            'd122:
              begin
                sin_value_o <= 'h1b2;
                cos_value_o <= 'h2f1;
                write_en <= 1'b1;
                write_addr <= 'd122;
              end
            'd123:
              begin
                sin_value_o <= 'h1ad;
                cos_value_o <= 'h2e9;
                write_en <= 1'b1;
                write_addr <= 'd122;
              end
            'd124:
              begin
                sin_value_o <= 'h1a8;
                cos_value_o <= 'h2e2;
                write_en <= 1'b1;
                write_addr <= 'd124;
              end
            'd125:
              begin
                sin_value_o <= 'h1a3;
                cos_value_o <= 'h2da;
                write_en <= 1'b1;
                write_addr <= 'd125;
              end
            'd126:
              begin
                sin_value_o <= 'h19e;
                cos_value_o <= 'h2d3;
                write_en <= 1'b1;
                write_addr <= 'd126;
              end
            'd127:
              begin
                sin_value_o <= 'h199;
                cos_value_o <= 'h2cc;
                write_en <= 1'b1;
                write_addr <= 'd127;
              end
            'd128:
              begin
                sin_value_o <= 'h193;
                cos_value_o <= 'h2c5;
                write_en <= 1'b1;
                write_addr <= 'd128;
              end
            'd129:
              begin
                sin_value_o <= 'h18e;
                cos_value_o <= 'h2be;
                write_en <= 1'b1;
                write_addr <= 'd129;
              end
            'd130:
              begin
                sin_value_o <= 'h188;
                cos_value_o <= 'h2b7;
                write_en <= 1'b1;
                write_addr <= 'd130;
              end
            'd131:
              begin
                sin_value_o <= 'h182;
                cos_value_o <= 'h2b0;
                write_en <= 1'b1;
                write_addr <= 'd131;
              end
            'd132:
              begin
                sin_value_o <= 'h17c;
                cos_value_o <= 'h2a9;
                write_en <= 1'b1;
                write_addr <= 'd132;
              end
            'd133:
              begin
                sin_value_o <= 'h176;
                cos_value_o <= 'h2a3;
                write_en <= 1'b1;
                write_addr <= 'd133;
              end
            'd134:
              begin
                sin_value_o <= 'h170;
                cos_value_o <= 'h29c;
                write_en <= 1'b1;
                write_addr <= 'd134;
              end
            'd135:
              begin
                sin_value_o <= 'h16a;
                cos_value_o <= 'h296;
                write_en <= 1'b1;
                write_addr <= 'd135;
              end
            'd136:
              begin
                sin_value_o <= 'h164;
                cos_value_o <= 'h290;
                write_en <= 1'b1;
                write_addr <= 'd136;
              end
            'd137:
              begin
                sin_value_o <= 'h15d;
                cos_value_o <= 'h28a;
                write_en <= 1'b1;
                write_addr <= 'd137;
              end
            'd138:
              begin
                sin_value_o <= 'h157;
                cos_value_o <= 'h284;
                write_en <= 1'b1;
                write_addr <= 'd138;
              end
            'd139:
              begin
                sin_value_o <= 'h150;
                cos_value_o <= 'h27e;
                write_en <= 1'b1;
                write_addr <= 'd139;
              end
            'd140:
              begin
                sin_value_o <= 'h149;
                cos_value_o <= 'h278;
                write_en <= 1'b1;
                write_addr <= 'd140;
              end
            'd141:
              begin
                sin_value_o <= 'h142;
                cos_value_o <= 'h272;
                write_en <= 1'b1;
                write_addr <= 'd141;
              end
            'd142:
              begin
                sin_value_o <= 'h13b;
                cos_value_o <= 'h26d;
                write_en <= 1'b1;
                write_addr <= 'd142;
              end
            'd143:
              begin
                sin_value_o <= 'h134;
                cos_value_o <= 'h267;
                write_en <= 1'b1;
                write_addr <= 'd143;
              end
            'd144:
              begin
                sin_value_o <= 'h12d;
                cos_value_o <= 'h262;
                write_en <= 1'b1;
                write_addr <= 'd144;
              end
            'd145:
              begin
                sin_value_o <= 'h126;
                cos_value_o <= 'h25d;
                write_en <= 1'b1;
                write_addr <= 'd145;
              end
            'd146:
              begin
                sin_value_o <= 'h11e;
                cos_value_o <= 'h258;
                write_en <= 1'b1;
                write_addr <= 'd146;
              end
            'd147:
              begin
                sin_value_o <= 'h117;
                cos_value_o <= 'h253;
                write_en <= 1'b1;
                write_addr <= 'd147;
              end
            'd148:
              begin
                sin_value_o <= 'h10f;
                cos_value_o <= 'h24e;
                write_en <= 1'b1;
                write_addr <= 'd148;
              end
            'd149:
              begin
                sin_value_o <= 'h108;
                cos_value_o <= 'h249;
                write_en <= 1'b1;
                write_addr <= 'd149;
              end
            'd150:
              begin
                sin_value_o <= 'h100;
                cos_value_o <= 'h245;
                write_en <= 1'b1;
                write_addr <= 'd150;
              end
            'd151:
              begin
                sin_value_o <= 'h0f8;
                cos_value_o <= 'h240;
                write_en <= 1'b1;
                write_addr <= 'd151;
              end
            'd152:
              begin
                sin_value_o <= 'h0f0;
                cos_value_o <= 'h23c;
                write_en <= 1'b1;
                write_addr <= 'd152;
              end
            'd153:
              begin
                sin_value_o <= 'h0e8;
                cos_value_o <= 'h238;
                write_en <= 1'b1;
                write_addr <= 'd153;
              end
            'd154:
              begin
                sin_value_o <= 'h0e0;
                cos_value_o <= 'h234;
                write_en <= 1'b1;
                write_addr <= 'd154;
              end
            'd155:
              begin
                sin_value_o <= 'h0d8;
                cos_value_o <= 'h230;
                write_en <= 1'b1;
                write_addr <= 'd155;
              end
            'd156:
              begin
                sin_value_o <= 'h0d0;
                cos_value_o <= 'h22c;
                write_en <= 1'b1;
                write_addr <= 'd156;
              end
            'd157:
              begin
                sin_value_o <= 'h0c8;
                cos_value_o <= 'h229;
                write_en <= 1'b1;
                write_addr <= 'd157;
              end
            'd158:
              begin
                sin_value_o <= 'h0c0;
                cos_value_o <= 'h225;
                write_en <= 1'b1;
                write_addr <= 'd158;
              end
            'd159:
              begin
                sin_value_o <= 'h0b7;
                cos_value_o <= 'h222;
                write_en <= 1'b1;
                write_addr <= 'd159;
              end
            'd160:
              begin
                sin_value_o <= 'h0af;
                cos_value_o <= 'h21f;
                write_en <= 1'b1;
                write_addr <= 'd160;
              end
            'd161:
              begin
                sin_value_o <= 'h0a7;
                cos_value_o <= 'h21c;
                write_en <= 1'b1;
                write_addr <= 'd161;
              end
            'd162:
              begin
                sin_value_o <= 'h09e;
                cos_value_o <= 'h219;
                write_en <= 1'b1;
                write_addr <= 'd162;
              end
            'd163:
              begin
                sin_value_o <= 'h096;
                cos_value_o <= 'h216;
                write_en <= 1'b1;
                write_addr <= 'd163;
              end
            'd164:
              begin
                sin_value_o <= 'h08d;
                cos_value_o <= 'h214;
                write_en <= 1'b1;
                write_addr <= 'd164;
              end
            'd165:
              begin
                sin_value_o <= 'h085;
                cos_value_o <= 'h211;
                write_en <= 1'b1;
                write_addr <= 'd165;
              end
            'd166:
              begin
                sin_value_o <= 'h07c;
                cos_value_o <= 'h20f;
                write_en <= 1'b1;
                write_addr <= 'd166;
              end
            'd167:
              begin
                sin_value_o <= 'h073;
                cos_value_o <= 'h20d;
                write_en <= 1'b1;
                write_addr <= 'd167;
              end
            'd168:
              begin
                sin_value_o <= 'h06a;
                cos_value_o <= 'h20b;
                write_en <= 1'b1;
                write_addr <= 'd168;
              end
            'd169:
              begin
                sin_value_o <= 'h062;
                cos_value_o <= 'h209;
                write_en <= 1'b1;
                write_addr <= 'd169;
              end
            'd170:
              begin
                sin_value_o <= 'h059;
                cos_value_o <= 'h208;
                write_en <= 1'b1;
                write_addr <= 'd170;
              end
            'd171:
              begin
                sin_value_o <= 'h050;
                cos_value_o <= 'h206;
                write_en <= 1'b1;
                write_addr <= 'd171;
              end
            'd172:
              begin
                sin_value_o <= 'h047;
                cos_value_o <= 'h205;
                write_en <= 1'b1;
                write_addr <= 'd172;
              end
            'd173:
              begin
                sin_value_o <= 'h03e;
                cos_value_o <= 'h204;
                write_en <= 1'b1;
                write_addr <= 'd173;
              end
            'd174:
              begin
                sin_value_o <= 'h036;
                cos_value_o <= 'h203;
                write_en <= 1'b1;
                write_addr <= 'd174;
              end
            'd175:
              begin
                sin_value_o <= 'h02d;
                cos_value_o <= 'h202;
                write_en <= 1'b1;
                write_addr <= 'd175;
              end
            'd176:
              begin
                sin_value_o <= 'h024;
                cos_value_o <= 'h201;
                write_en <= 1'b1;
                write_addr <= 'd176;
              end
            'd177:
              begin
                sin_value_o <= 'h01b;
                cos_value_o <= 'h201;
                write_en <= 1'b1;
                write_addr <= 'd177;
              end
            'd178:
              begin
                sin_value_o <= 'h012;
                cos_value_o <= 'h200;
                write_en <= 1'b1;
                write_addr <= 'd178;
              end
            'd179:
              begin
                sin_value_o <= 'h009;
                cos_value_o <= 'h200;
                write_en <= 1'b1;
                write_addr <= 'd179;
              end
            'd180:
              begin
                sin_value_o <= 'h000;
                cos_value_o <= 'h200;
                write_en <= 1'b1;
                write_addr <= 'd180;
              end
            'd181:
              begin
                sin_value_o <= 'h000;
                cos_value_o <= 'h200;
                write_en <= 1'b0;
                write_addr <= 'd180;
              end
          endcase
        end
    end
endmodule
