/*****************************************************************************************************************************
--
--    File Name    : cdcfifo.v

--    Description  : This module implements CDC fifo                                 

-- Targeted device : Microsemi-SoC                     
-- Author          : India Solutions Team

-- SVN Revision Information:
-- SVN $Revision: TBD
-- SVN $Date: TBD
--
--
--
-- COPYRIGHT 2018 BY MICROSEMI 
-- THE INFORMATION CONTAINED IN THIS DOCUMENT IS SUBJECT TO LICENSING RESTRICTIONS 
-- FROM MICROSEMI CORP.  IF YOU ARE NOT IN POSSESSION OF WRITTEN AUTHORIZATION FROM 
-- MICROSEMI FOR USE OF THIS FILE, THEN THE FILE SHOULD BE IMMEDIATELY DESTROYED AND 
-- NO BACK-UP OF THE FILE SHOULD BE MADE. 
-- 

--******************************************************************************************************************************/
`timescale 1ns/1ps
module cdcfifo #(parameter[3 : 0] ADDR_WIDTH = 12,
                 parameter[7 : 0] DATA_WIDTH = 8)
               (k_lim,
                wrrstn,
                wrclk,
                wrreq,
                wrdata,
                wrfull,
                wrusedw,
                rdrstn,
                rdclk,
                rdreq,
                rddata,
                rdempty,
                rdusedw);
  input[ADDR_WIDTH - 1 : 0] k_lim;
  input wrrstn;
  input wrclk;
  input wrreq;
  input[(DATA_WIDTH - 1) : 0] wrdata;
  output reg wrfull;
  output[(ADDR_WIDTH - 1) : 0] wrusedw;
  input rdrstn;
  input rdclk;
  input rdreq;
  output[(DATA_WIDTH - 1) : 0] rddata;
  output rdempty;
  output reg[(ADDR_WIDTH - 1) : 0] rdusedw;
  parameter[31 : 0] l1I = 32'h00000001;
  parameter[31 : 0] o1I = 32'h00000003;
  wire i1I;
  wire OoI;
  wire IoI;
  reg[(ADDR_WIDTH - 1) : 0] loI;
  reg[(ADDR_WIDTH - 1) : 0] ooI;
  reg[(ADDR_WIDTH - 1) : 0] ioI;
  reg[(ADDR_WIDTH - 1) : 0] OiI;
  reg[(ADDR_WIDTH - 1) : 0] IiI;
  reg[(ADDR_WIDTH - 1) : 0] liI;
  reg[(ADDR_WIDTH - 1) : 0] oiI;
  reg[(ADDR_WIDTH - 1) : 0] iiI;
  reg[(ADDR_WIDTH - 1) : 0] OOl;
  reg[(ADDR_WIDTH - 1) : 0] IOl;
  reg[(ADDR_WIDTH - 1) : 0] lOl;
  reg[(ADDR_WIDTH - 1) : 0] oOl;
  wire[(ADDR_WIDTH - 2) : 0] iOl;
  reg OIl,
      IIl;
  assign iOl = { ADDR_WIDTH - 1 { 1'b0 } };
  cdcfiforam #(.ADDR_WIDTH(ADDR_WIDTH), .DATA_WIDTH(DATA_WIDTH)) lIl(.data(wrdata),
                                                                     .wren(OoI),
                                                                     .wraddress(IiI),
                                                                     .rdaddress(loI),
                                                                     .wrclock(wrclk),
                                                                     .rdclock(rdclk),
                                                                     .q(rddata));
  always
    @(oiI or
      iOl)
    begin: oIl
      reg[(ADDR_WIDTH - 1) : 0] iIl;
      reg Oll;
      integer o;
      integer Ill;
      iIl[(ADDR_WIDTH - 1)] = oiI[(ADDR_WIDTH - 1)];
      iIl[(ADDR_WIDTH - 2) : 0] = iOl;
      Oll = 1'b0;
      for (o = 0; o <= (ADDR_WIDTH - 1); o = o + 1)
        begin
          for (Ill = o; Ill <= (ADDR_WIDTH - 1); Ill = Ill + 1)
            iIl[o] = iIl[o] ^ oiI[Ill];
          OOl[o] <= oiI[o] ^ ((~Oll) & (~iIl[o]));
          Oll = Oll | (~iIl[o]);
        end
    end
  always
    @(negedge wrrstn or
      posedge wrclk)
    begin: lll
      reg[(ADDR_WIDTH - 1) : 0] oll;
      reg[(ADDR_WIDTH - 1) : 0] ill;
      integer o;
      if (wrrstn == 1'b0)
        begin
          IiI <= { ADDR_WIDTH { 1'b0 } };
          liI <= { ADDR_WIDTH { 1'b0 } };
          iiI <= l1I[(ADDR_WIDTH - 1) : 0];
          oiI <= o1I[(ADDR_WIDTH - 1) : 0];
          ioI <= { ADDR_WIDTH { 1'b0 } };
          OiI <= { ADDR_WIDTH { 1'b0 } };
          oOl <= { ADDR_WIDTH { 1'b0 } };
          wrfull <= 1'b0;
          ill = { ADDR_WIDTH { 1'b0 } };
          oll = { ADDR_WIDTH { 1'b0 } };
        end
      else
        begin
          if (OoI == 1'b1)
            begin
              oiI <= OOl;
              iiI <= oiI;
              IiI <= iiI;
            end
          liI <= IiI;
          ioI <= loI;
          OiI <= ioI;
          oll[(ADDR_WIDTH - 1)] = liI[(ADDR_WIDTH - 1)];
          for (o = (ADDR_WIDTH - 2); o >= 0; o = o - 1)
            oll[o] = oll[o + 1] ^ liI[o];
          ill[(ADDR_WIDTH - 1)] = OiI[(ADDR_WIDTH - 1)];
          for (o = (ADDR_WIDTH - 2); o >= 0; o = o - 1)
            ill[o] = ill[o + 1] ^ OiI[o];
          if (oOl >= k_lim)
            wrfull <= 1'b1;
          else
            wrfull <= 1'b0;
          { IIl, oOl } <= oll - ill;
        end
    end
  assign wrusedw = oOl;
  assign OoI = wrreq;
  always
    @(loI or
      i1I or
      iOl)
    begin: O0l
      reg[(ADDR_WIDTH - 1) : 0] iIl;
      reg Oll;
      integer o;
      integer Ill;
      iIl[(ADDR_WIDTH - 1)] = loI[(ADDR_WIDTH - 1)];
      iIl[(ADDR_WIDTH - 2) : 0] = iOl;
      Oll = 1'b0;
      for (o = 0; o <= (ADDR_WIDTH - 1); o = o + 1)
        begin
          for (Ill = o; Ill <= (ADDR_WIDTH - 1); Ill = Ill + 1)
            iIl[o] = iIl[o] ^ loI[Ill];
          ooI[o] <= loI[o] ^ (i1I & (~Oll) & (~iIl[o]));
          Oll = Oll | (~iIl[o]);
        end
    end
  always
    @(negedge rdrstn or
      posedge rdclk)
    begin: I0l
      reg[(ADDR_WIDTH - 1) : 0] l0l;
      reg[(ADDR_WIDTH - 1) : 0] o0l;
      integer o;
      if (rdrstn == 1'b0)
        begin
          loI <= { ADDR_WIDTH { 1'b0 } };
          IOl <= { ADDR_WIDTH { 1'b0 } };
          lOl <= { ADDR_WIDTH { 1'b0 } };
          rdusedw <= { ADDR_WIDTH { 1'b0 } };
          l0l = { ADDR_WIDTH { 1'b0 } };
          o0l = { ADDR_WIDTH { 1'b0 } };
        end
      else
        begin
          loI <= ooI;
          IOl <= liI;
          lOl <= IOl;
          o0l[(ADDR_WIDTH - 1)] = lOl[(ADDR_WIDTH - 1)];
          for (o = (ADDR_WIDTH - 2); o >= 0; o = o - 1)
            o0l[o] = o0l[o + 1] ^ lOl[o];
          l0l[(ADDR_WIDTH - 1)] = loI[(ADDR_WIDTH - 1)];
          for (o = (ADDR_WIDTH - 2); o >= 0; o = o - 1)
            l0l[o] = l0l[o + 1] ^ loI[o];
          { OIl, rdusedw } <= o0l - l0l;
        end
    end
  assign IoI = (lOl == loI) ? 1'b1 : 1'b0;
  assign rdempty = IoI;
  assign i1I = rdreq & (~IoI);
endmodule
